# coding: utf-8

"""
    CardScan API

    The official documentation for the CardScan API.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class AddressType(str, Enum):
    """
    AddressType
    """

    """
    allowed enum values
    """
    MEDICAL_CLAIMS_ADDRESS = 'medical_claims_address'
    PHARMACY_CLAIMS_ADDRESS = 'pharmacy_claims_address'
    VISION_CLAIMS_ADDRESS = 'vision_claims_address'
    DENTAL_CLAIMS_ADDRESS = 'dental_claims_address'
    APPEALS_ADDRESS = 'appeals_address'
    PCP_ADDRESS = 'pcp_address'
    GENERAL_ADDRESS = 'general_address'

    @classmethod
    def from_json(cls, json_str: str) -> AddressType:
        """Create an instance of AddressType from a JSON string"""
        return AddressType(json.loads(json_str))





# coding: utf-8

"""
    CardScan API

    The official documentation for the CardScan API.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class CopayDeductibleService(str, Enum):
    """
    CopayDeductibleService
    """

    """
    allowed enum values
    """
    OFFICE_VISIT = 'office_visit'
    SPECIALIST_VISIT = 'specialist_visit'
    EMERGENCY_ROOM = 'emergency_room'
    URGENT_CARE = 'urgent_care'
    PREVENTIVE_CARE = 'preventive_care'
    PRESCRIPTION = 'prescription'
    VISION = 'vision'
    DENTAL = 'dental'
    TELEMEDICINE = 'telemedicine'
    IN_NETWORK_MEDICAL = 'in_network_medical'
    OUT_OF_NETWORK_MEDICAL = 'out_of_network_medical'
    OTHER = 'other'

    @classmethod
    def from_json(cls, json_str: str) -> CopayDeductibleService:
        """Create an instance of CopayDeductibleService from a JSON string"""
        return CopayDeductibleService(json.loads(json_str))





# coding: utf-8

"""
    CardScan API

    The official documentation for the CardScan API.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr

class GetAccessToken200Response(BaseModel):
    """
    GetAccessToken200Response
    """
    token: StrictStr = Field(default=..., alias="Token", description="The access token.")
    identity_id: StrictStr = Field(default=..., alias="IdentityId", description="The identity ID.")
    session_id: Optional[StrictStr] = Field(default=None, description="The session ID.")
    __properties = ["Token", "IdentityId", "session_id"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def _json_serializer(self, obj):
        """JSON serializer function for datetime objects"""
        if isinstance(obj, datetime):
            return obj.isoformat()

        raise TypeError(f"Type {type(obj)} not serializable")

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict(), default=self._json_serializer)

    @classmethod
    def from_json(cls, json_str: str) -> GetAccessToken200Response:
        """Create an instance of GetAccessToken200Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> GetAccessToken200Response:
        """Create an instance of GetAccessToken200Response from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return GetAccessToken200Response.parse_obj(obj)

        _obj = GetAccessToken200Response.parse_obj({
            "token": obj.get("Token"),
            "identity_id": obj.get("IdentityId"),
            "session_id": obj.get("session_id")
        })
        return _obj





# coding: utf-8

"""
    CardScan API

    The official documentation for the CardScan API.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, StrictStr, conlist
from cardscan_client.models.chc_payer_record import CHCPayerRecord
from cardscan_client.models.custom_payer_record import CustomPayerRecord

class PayerMatch(BaseModel):
    """
    PayerMatch
    """
    cardscan_payer_id: Optional[StrictStr] = None
    cardscan_payer_name: Optional[StrictStr] = None
    score: Optional[StrictStr] = None
    change_healthcare: Optional[conlist(CHCPayerRecord)] = None
    custom: Optional[conlist(CustomPayerRecord)] = None
    message: Optional[StrictStr] = None
    __properties = ["cardscan_payer_id", "cardscan_payer_name", "score", "change_healthcare", "custom", "message"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def _json_serializer(self, obj):
        """JSON serializer function for datetime objects"""
        if isinstance(obj, datetime):
            return obj.isoformat()

        raise TypeError(f"Type {type(obj)} not serializable")

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict(), default=self._json_serializer)

    @classmethod
    def from_json(cls, json_str: str) -> PayerMatch:
        """Create an instance of PayerMatch from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in change_healthcare (list)
        _items = []
        if self.change_healthcare:
            for _item in self.change_healthcare:
                if _item:
                    _items.append(_item.to_dict())
            _dict['change_healthcare'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in custom (list)
        _items = []
        if self.custom:
            for _item in self.custom:
                if _item:
                    _items.append(_item.to_dict())
            _dict['custom'] = _items
        # set to None if cardscan_payer_id (nullable) is None
        # and __fields_set__ contains the field
        if self.cardscan_payer_id is None and "cardscan_payer_id" in self.__fields_set__:
            _dict['cardscan_payer_id'] = None

        # set to None if cardscan_payer_name (nullable) is None
        # and __fields_set__ contains the field
        if self.cardscan_payer_name is None and "cardscan_payer_name" in self.__fields_set__:
            _dict['cardscan_payer_name'] = None

        # set to None if score (nullable) is None
        # and __fields_set__ contains the field
        if self.score is None and "score" in self.__fields_set__:
            _dict['score'] = None

        # set to None if change_healthcare (nullable) is None
        # and __fields_set__ contains the field
        if self.change_healthcare is None and "change_healthcare" in self.__fields_set__:
            _dict['change_healthcare'] = None

        # set to None if custom (nullable) is None
        # and __fields_set__ contains the field
        if self.custom is None and "custom" in self.__fields_set__:
            _dict['custom'] = None

        # set to None if message (nullable) is None
        # and __fields_set__ contains the field
        if self.message is None and "message" in self.__fields_set__:
            _dict['message'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PayerMatch:
        """Create an instance of PayerMatch from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return PayerMatch.parse_obj(obj)

        _obj = PayerMatch.parse_obj({
            "cardscan_payer_id": obj.get("cardscan_payer_id"),
            "cardscan_payer_name": obj.get("cardscan_payer_name"),
            "score": obj.get("score"),
            "change_healthcare": [CHCPayerRecord.from_dict(_item) for _item in obj.get("change_healthcare")] if obj.get("change_healthcare") is not None else None,
            "custom": [CustomPayerRecord.from_dict(_item) for _item in obj.get("custom")] if obj.get("custom") is not None else None,
            "message": obj.get("message")
        })
        return _obj





# coding: utf-8

"""
    CardScan API

    The official documentation for the CardScan API.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class CopayCategory(str, Enum):
    """
    CopayCategory
    """

    """
    allowed enum values
    """
    COPAY = 'copay'
    COINSURANCE = 'coinsurance'
    DEDUCTIBLE = 'deductible'
    OUT_OF_POCKET_MAX = 'out_of_pocket_max'
    OTHER = 'other'

    @classmethod
    def from_json(cls, json_str: str) -> CopayCategory:
        """Create an instance of CopayCategory from a JSON string"""
        return CopayCategory(json.loads(json_str))





# coding: utf-8

"""
    CardScan API

    The official documentation for the CardScan API.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class PhoneNumberType(str, Enum):
    """
    PhoneNumberType
    """

    """
    allowed enum values
    """
    PCP_PHONE = 'pcp_phone'
    MEMBER_SERVICES_PHONE = 'member_services_phone'
    PROVIDER_SERVICES_PHONE = 'provider_services_phone'
    PHARMACY_SERVICES_PHONE = 'pharmacy_services_phone'
    DENTAL_BENEFIT_PHONE = 'dental_benefit_phone'
    VISION_BENEFIT_PHONE = 'vision_benefit_phone'
    TELEMEDICINE_PHONE = 'telemedicine_phone'

    @classmethod
    def from_json(cls, json_str: str) -> PhoneNumberType:
        """Create an instance of PhoneNumberType from a JSON string"""
        return PhoneNumberType(json.loads(json_str))


